Learn R Programming

retrocombinator (version 1.0.0)

FamilyParams: Create FamilyParams object

Description

Create FamilyParams object

Usage

FamilyParams(familyCoherence = 0.7, maxFamilyRepresentatives = 20)

Arguments

familyCoherence

What sequence similarity do two sequences have to be to each other for them to be considered to be of the same family?

maxFamilyRepresentatives

How many family representatives to keep track of during the simulation?

Value

A bundling of the parameters given to it as a FamilyParams object

Examples

Run this code
# NOT RUN {
familyParams <- FamilyParams(familyCoherence = 0.775)
# }

Run the code above in your browser using DataLab