powered by
Create FamilyParams object
FamilyParams(familyCoherence = 0.7, maxFamilyRepresentatives = 20)
What sequence similarity do two sequences have to be to each other for them to be considered to be of the same family?
How many family representatives to keep track of during the simulation?
A bundling of the parameters given to it as a FamilyParams object
# NOT RUN { familyParams <- FamilyParams(familyCoherence = 0.775) # }
Run the code above in your browser using DataLab